@@ -574,7 +574,7 @@ int is_msg_for_me(snac *snac, const xs_dict *c_msg)
         return 0;
     }
 
-    if (xs_match(type, "Like|Announce")) {
+    if (xs_match(type, "Like|Announce|EmojiReact")) {
         const char *object = xs_dict_get(c_msg, "object");
 
         if (xs_type(object) == XSTYPE_DICT)
@@ -834,7 +834,7 @@ void notify(snac *snac, const char *type, const char *utype, const char *actor,
     if (xs_type(objid) == XSTYPE_DICT)
         objid = xs_dict_get(objid, "id");
 
-    if (strcmp(type, "Like") == 0 || strcmp(type, "Announce") == 0) {
+    if (xs_match(type, "Like|Announce|EmojiReact")) {
         /* if it's not an admiration about something by us, done */
         if (xs_is_null(objid) || !xs_startswith(objid, snac->actor))
             return;
@@ -927,13 +927,6 @@ void notify(snac *snac, const char *type, const char *utype, const char *actor,
     if (!xs_is_null(bot) && !xs_is_null(chat_id) && *bot && *chat_id)
         enqueue_telegram(body, bot, chat_id);
 
-    /* finally, store it in the notification folder */
-    if (strcmp(type, "Follow") == 0)
-        objid = id;
-    else
-    if (strcmp(utype, "Follow") == 0)
-        objid = actor;
-
     /* ntfy */
     const char *ntfy_server = xs_dict_get(snac->config, "ntfy_server");
     const char *ntfy_token  = xs_dict_get(snac->config, "ntfy_token");
@@ -941,6 +934,14 @@ void notify(snac *snac, const char *type, const char *utype, const char *actor,
     if (!xs_is_null(ntfy_server) && *ntfy_server)
         enqueue_ntfy(body, ntfy_server, ntfy_token);
 
+    /* auto boost */
+    if (xs_match(type, "Create") && xs_is_true(xs_dict_get(snac->config, "auto_boost"))) {
+        xs *msg = msg_admiration(snac, objid, "Announce");
+        enqueue_message(snac, msg);
+
+        snac_debug(snac, 1, xs_fmt("auto boosted %s", objid));
+    }
+
     /* finally, store it in the notification folder */
     if (strcmp(type, "Follow") == 0)
         objid = id;
@@ -948,7 +949,7 @@ void notify(snac *snac, const char *type, const char *utype, const char *actor,
     if (strcmp(utype, "Follow") == 0)
         objid = actor;
 
-    notify_add(snac, type, utype, actor, objid != NULL ? objid : id);
+    notify_add(snac, type, utype, actor, objid != NULL ? objid : id, msg);
 }
 
 /** messages **/
@@ -1162,7 +1163,7 @@ xs_dict *msg_actor(snac *snac)
     msg = xs_dict_set(msg, "summary", f_bio);
     msg = xs_dict_set(msg, "tag", tags);
 
-    char *folders[] = { "inbox", "outbox", "followers", "following", NULL };
+    char *folders[] = { "inbox", "outbox", "followers", "following", "featured", NULL };
     for (n = 0; folders[n]; n++) {
         xs *f = xs_fmt("%s/%s", snac->actor, folders[n]);
         msg = xs_dict_set(msg, folders[n], f);
@@ -1720,7 +1721,7 @@ int process_input_message(snac *snac, const xs_dict *msg, const xs_dict *req)
         type = "Note";
 
     /* reject uninteresting messages right now */
-    if (xs_match(type, "Add|View")) {
+    if (xs_match(type, "Add|View|Reject|Read|Remove")) {
         srv_debug(0, xs_fmt("Ignored message of type '%s'", type));
         return -1;
     }
@@ -1900,10 +1901,10 @@ int process_input_message(snac *snac, const xs_dict *msg, const xs_dict *req)
             }
         }
         else
-        if (strcmp(utype, "Like") == 0) { /** **/
+        if (strcmp(utype, "Like") == 0 || strcmp(utype, "EmojiReact") == 0) { /** **/
             int status = object_unadmire(id, actor, 1);
 
-            snac_log(snac, xs_fmt("Unlike for %s %d", id, status));
+            snac_log(snac, xs_fmt("Undo '%s' for %s %d", utype, id, status));
         }
         else
         if (strcmp(utype, "Announce") == 0) { /** **/
@@ -2013,12 +2014,12 @@ int process_input_message(snac *snac, const xs_dict *msg, const xs_dict *req)
         }
     }
     else
-    if (strcmp(type, "Like") == 0) { /** **/
+    if (strcmp(type, "Like") == 0 || strcmp(type, "EmojiReact") == 0) { /** **/
         if (xs_type(object) == XSTYPE_DICT)
             object = xs_dict_get(object, "id");
 
         if (timeline_admire(snac, object, actor, 1) == HTTP_STATUS_CREATED)
-            snac_log(snac, xs_fmt("new 'Like' %s %s", actor, object));
+            snac_log(snac, xs_fmt("new '%s' %s %s", type, actor, object));
         else
             snac_log(snac, xs_fmt("repeated 'Like' from %s to %s", actor, object));
 
@@ -2133,6 +2134,73 @@ int process_input_message(snac *snac, const xs_dict *msg, const xs_dict *req)
 
         enqueue_output_by_actor(snac, rsp, actor, 0);
     }
+    else
+    if (strcmp(type, "Block") == 0) { /** **/
+        snac_log(snac, xs_fmt("'Block' received from %s", actor));
+
+        /* should we MUTE the actor back? */
+        /* mute(snac, actor); */
+
+        do_notify = 1;
+    }
+    else
+    if (strcmp(type, "Move") == 0) { /** **/
+        do_notify = 1;
+
+        const char *old_account = xs_dict_get(msg, "object");
+        const char *new_account = xs_dict_get(msg, "target");
+
+        if (!xs_is_null(old_account) && !xs_is_null(new_account)) {
+            if (following_check(snac, old_account)) {
+                xs *n_actor = NULL;
+
+                if (valid_status(object_get(new_account, &n_actor))) {
+                    const xs_list *aka = xs_dict_get(n_actor, "alsoKnownAs");
+
+                    if (xs_type(aka) == XSTYPE_LIST) {
+                        if (xs_list_in(aka, old_account) != -1) {
+                            /* all conditions met! */
+
+                            /* follow new account */
+                            xs *f_msg = msg_follow(snac, new_account);
+
+                            if (f_msg != NULL) {
+                                const char *new_actor = xs_dict_get(f_msg, "object");
+                                following_add(snac, new_actor, f_msg);
+                                enqueue_output_by_actor(snac, f_msg, new_actor, 0);
+
+                                snac_log(snac, xs_fmt("'Move': following %s", new_account));
+                            }
+
+                            /* unfollow old account */
+                            xs *of_msg = NULL;
+
+                            if (valid_status(following_get(snac, old_account, &of_msg))) {
+                                xs *uf_msg = msg_undo(snac, xs_dict_get(of_msg, "object"));
+                                following_del(snac, old_account);
+                                enqueue_output_by_actor(snac, uf_msg, old_account, 0);
+
+                                snac_log(snac, xs_fmt("'Move': unfollowing %s", old_account));
+                            }
+                        }
+                        else
+                            snac_log(snac, xs_fmt("'Move' error: old actor %s not found in %s 'alsoKnownAs'",
+                                old_account, new_account));
+                    }
+                    else
+                        snac_log(snac, xs_fmt("'Move' error: cannot get %s 'alsoKnownAs'", new_account));
+                }
+                else
+                    snac_log(snac, xs_fmt("'Move' error: cannot get new actor %s", new_account));
+            }
+            else
+                snac_log(snac, xs_fmt("'Move' error: actor %s is not being followed", old_account));
+        }
+        else {
+            snac_log(snac, xs_fmt("'Move' error: malformed message from %s", actor));
+            srv_archive_error("move", "move", req, msg);
+        }
+    }
     else {
         srv_archive_error("unsupported_type", "unsupported_type", req, msg);
 
@@ -2189,16 +2257,16 @@ void process_user_queue_item(snac *snac, xs_dict *q_item)
 
     if (strcmp(type, "message") == 0) {
         const xs_dict *msg = xs_dict_get(q_item, "message");
-        xs *rcpts    = recipient_list(snac, msg, 1);
+        xs *rcpts = recipient_list(snac, msg, 1);
         xs_set inboxes;
-        xs_list *p;
         const xs_str *actor;
+        int c;
 
         xs_set_init(&inboxes);
 
         /* iterate the recipients */
-        p = rcpts;
-        while (xs_list_iter(&p, &actor)) {
+        c = 0;
+        while (xs_list_next(rcpts, &actor, &c)) {
             xs *inbox = get_actor_inbox(actor);
 
             if (inbox != NULL) {
@@ -2210,14 +2278,14 @@ void process_user_queue_item(snac *snac, xs_dict *q_item)
                 snac_log(snac, xs_fmt("cannot find inbox for %s", actor));
         }
 
-        /* if it's public, send to the collected inboxes */
-        if (is_msg_public(msg)) {
+        /* if it's a public note or question, send to the collected inboxes */
+        if (xs_match(xs_dict_get_def(msg, "type", ""), "Create|Update") && is_msg_public(msg)) {
             if (xs_type(xs_dict_get(srv_config, "disable_inbox_collection")) != XSTYPE_TRUE) {
                 xs *shibx = inbox_list();
                 const xs_str *inbox;
 
-                p = shibx;
-                while (xs_list_iter(&p, &inbox)) {
+                c = 0;
+                while (xs_list_next(shibx, &inbox, &c)) {
                     if (xs_set_add(&inboxes, inbox) == 1)
                         enqueue_output(snac, msg, inbox, 0, 0);
                 }
@@ -2237,8 +2305,6 @@ void process_user_queue_item(snac *snac, xs_dict *q_item)
             return;
 
         if (!process_input_message(snac, msg, req)) {
-            srv_archive_error("input", "process_input_message", req, msg);
-
             if (retries > queue_retry_max)
                 snac_log(snac, xs_fmt("input giving up"));
             else {
@@ -2393,6 +2459,7 @@ void process_queue_item(xs_dict *q_item)
                 || status == HTTP_STATUS_NOT_FOUND
                 || status == HTTP_STATUS_METHOD_NOT_ALLOWED
                 || status == HTTP_STATUS_GONE
+                || status == HTTP_STATUS_UNPROCESSABLE_CONTENT
                 || status < 0)
                 /* explicit error: discard */
                 srv_log(xs_fmt("output message: fatal error %s %d", inbox, status));
@@ -2543,7 +2610,6 @@ void process_queue_item(xs_dict *q_item)
             unlink(tmpfn);
 
             if (cnt == 0) {
-                srv_archive_qitem("no_valid_recipients", q_item);
                 srv_debug(1, xs_fmt("no valid recipients for %s", xs_dict_get(msg, "id")));
             }
         }
@@ -2617,16 +2683,17 @@ int activitypub_get_handler(const xs_dict *req, const char *q_path,
         snac_debug(&snac, 0, xs_fmt("serving actor [%s]", ua ? ua : "No UA"));
     }
     else
-    if (strcmp(p_path, "outbox") == 0) {
-        xs *id = xs_fmt("%s/outbox", snac.actor);
-        xs *elems = timeline_simple_list(&snac, "public", 0, 20);
+    if (strcmp(p_path, "outbox") == 0 || strcmp(p_path, "featured") == 0) {
+        xs *id = xs_fmt("%s/%s", snac.actor, p_path);
         xs *list = xs_list_new();
         msg = msg_collection(&snac, id);
-        char *p;
         const char *v;
+        int tc = 0;
 
-        p = elems;
-        while (xs_list_iter(&p, &v)) {
+        /* get the public outbox or the pinned list */
+        xs *elems = *p_path == 'o' ? timeline_simple_list(&snac, "public", 0, 20) : pinned_list(&snac);
+
+        while (xs_list_next(elems, &v, &tc)) {
             xs *i = NULL;
 
             if (valid_status(object_get_by_md5(v, &i))) {
